@@ -1,13 +1,6 @@
 #' Tests for an internet conection
 #'
-#' A helper function that testa and make sure the user has a live internet conection.
-#'
-#' @return Logical TRUE/FALSE
-#' @export
-#'
-#' @examples
-#'
-#' inet.flag <- gbcbd_test_internet()
+#' @noRd
 gbcbd_test_internet <- function() {
   # check for internet
   test.internet <- curl::has_internet()
@@ -21,13 +14,9 @@ gbcbd_test_internet <- function() {
 #'
 #' Internal use. USe the same default cache folder for all other functions.
 #'
-#' @return A path to directory
-#' @export
-#'
-#' @examples
-#' my.cache.folder <- gbcbd_get_default_cache_folder()
+#' @noRd
 gbcbd_get_default_cache_folder <- function() {
-  name.cache.dir <- 'gbcbd_cache'
+  name.cache.dir <- file.path(tempdir(), 'gbcbd_cache')
 
   return(name.cache.dir)
 }
@@ -36,13 +25,7 @@ gbcbd_get_default_cache_folder <- function() {
 #'
 #' Internal use. Simply switches a function given a choice for using memoise.
 #'
-#' @inheritParams gbcbd_get_series
-#' @return A JSON function that will use cache or not
-#' @export
-#'
-#' @examples
-#'
-#' fct_get_JSON <- gbcbd_get_JSON_fct(cache.path = tempdir())
+#' @noRd
 gbcbd_get_JSON_fct <- function(use.memoise = TRUE,
                                cache.path = gbcbd_get_default_cache_folder()) {
 
@@ -59,14 +42,7 @@ gbcbd_get_JSON_fct <- function(use.memoise = TRUE,
 
 #' Custom function for printing messages
 #'
-#' @param str.in Message string
-#' @param be.quiet Logical. Should print it or not?
-#'
-#' @return Nothing
-#' @export
-#'
-#' @examples
-#' gbcbd_message('Test', FALSE)
+#' @noRd
 gbcbd_message <- function(str.in, be.quiet) {
 
   if (be.quiet) {
